import { useSSRContext, ref, computed, mergeProps, unref } from 'vue';
import { ssrRenderAttrs, ssrInterpolate, ssrRenderStyle, ssrRenderList, ssrRenderAttr, ssrRenderClass } from 'vue/server-renderer';
import { _ as _export_sfc, e as useRoute, b as useAppState, f as useTfText, g as useModel, h as usePrettyCurrency, j as useRequest } from './server.mjs';

const _sfc_main = {
  __name: "ROrderSummary",
  __ssrInlineRender: true,
  props: {
    modelValue: { type: null, default: null },
    disabled: { type: Boolean, default: false },
    orderId: { type: null, default: null },
    scroll: { type: Boolean, default: true }
  },
  emits: ["change", "enter", "delete", "update:modelValue", "focus", "blur", "rchange", "escape"],
  setup(__props, { emit: __emit }) {
    let route = useRoute();
    useAppState();
    const props = __props;
    let tf = useTfText();
    const emit = __emit;
    useModel(props, emit);
    const the_order = ref(null);
    let is_loading = ref(false);
    const is_logged_in = ref(true);
    const order_id = computed(() => {
      return props.orderId ? props.orderId : route.query["order-id"];
    });
    let prettify = usePrettyCurrency();
    let fetch_order = async () => {
      is_loading.value = true;
      let from_checkout_page = route.path == "/checkout-complete";
      let url = from_checkout_page ? `/api/shop/check-session` : `/api/posts/${order_id.value}`;
      try {
        let query = from_checkout_page ? { order_id: order_id.value } : {};
        let res = await useRequest({ url, query });
        the_order.value = res.d;
        is_logged_in.value = true;
      } catch (e) {
        is_logged_in.value = false;
      }
      is_loading.value = false;
    };
    fetch_order();
    let product_title = computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        var summary = o_item.value.find((it) => it.type == "summary");
        if (summary) return summary.title;
        return null;
      };
    });
    let product_vendor = computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        var summary = o_item.value.find((it) => it.type == "summary");
        if (summary) return summary.vendor || "N/A";
        return null;
      };
    });
    computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        var summary = o_item.value.find((it) => it.type == "summary");
        if (summary) return summary.url;
        return null;
      };
    });
    let product_variant = computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        var summary = o_item.value.find((it) => it.type == "summary");
        if (summary) {
          if (!Array.isArray(summary.choices)) return "Default";
          let variant = summary.choices.find((it) => it.type == "variant");
          return variant;
        }
        return null;
      };
    });
    let meta = computed(() => {
      return (name) => {
        if (!the_order.value) return null;
        if (!Array.isArray(the_order.value.metas)) return null;
        let m = the_order.value.metas.find((it) => it.name == name);
        if (!m) {
          return `{${name}?}`;
        }
        return m.value;
      };
    });
    let product_choices = computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        var summary = o_item.value.find((it) => it.type == "summary");
        if (summary) {
          return summary.choices.filter((it) => it.type != "variant");
        }
        return null;
      };
    });
    let product_price = computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        var summary = o_item.value.find((it) => it.type == "summary");
        if (summary) return summary.price;
        return null;
      };
    });
    let product_status = computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        return o_item.status;
      };
    });
    let product_delivery = computed(() => {
      return (o_item) => {
        if (!Array.isArray(o_item.value)) return null;
        var summary = o_item.value.find((it) => it.type == "summary");
        if (summary) return summary.delivery || "N/A";
        return null;
      };
    });
    let order_items = computed(() => {
      if (!the_order.value) return null;
      if (!Array.isArray(the_order.value.order_items)) return null;
      return the_order.value.order_items.filter((it) => {
        return it.type.endsWith("_item");
      });
    });
    let order_item_styling = computed(() => {
      let s = {};
      if (props.scroll) {
        s.maxHeight = "600px";
        s.overflow = "auto";
      }
      return s;
    });
    return (_ctx, _push, _parent, _attrs) => {
      _push(`<div${ssrRenderAttrs(mergeProps({
        class: "rc order-summary",
        ref: "root"
      }, _attrs))} data-v-61b273d7>`);
      if (unref(is_loading)) {
        _push(`<div class="loader-spinner" data-v-61b273d7></div>`);
      } else {
        _push(`<!--[-->`);
        if (!unref(is_logged_in)) {
          _push(`<div class="error py-9 px-5 text-center" data-v-61b273d7><h3 class="text-md mb-5 color-red-500" data-v-61b273d7>Order Summary</h3><p class="color-red-700" data-v-61b273d7>Please login in order to view the order details for <span class="tag" data-v-61b273d7>${ssrInterpolate(__props.orderId)}</span>. </p></div>`);
        } else {
          _push(`<!--[-->`);
          if (!unref(the_order)) {
            _push(`<div class="olo-li" data-v-61b273d7><h3 class="text-md mb-5 color-red-500" data-v-61b273d7>Cannot find Order</h3><p class="color-red-700" data-v-61b273d7>Order <span class="tag" data-v-61b273d7>${ssrInterpolate(__props.orderId)}</span> could not be located or is not accessible at this time. </p></div>`);
          } else {
            _push(`<div data-v-61b273d7><h2 class="text-md color-primary-500 mb-2" data-v-61b273d7>${ssrInterpolate(unref(the_order).title)}</h2><p data-v-61b273d7>Created ${ssrInterpolate(unref(tf)(unref(the_order).created, { fmt: "text" }))}</p><div class="customer" data-v-61b273d7><div class="flex justify-between" data-v-61b273d7><span class="customer-name font-bold" data-v-61b273d7>${ssrInterpolate(unref(meta)("customer_name"))}</span><span class="customer-phone" data-v-61b273d7>${ssrInterpolate(unref(meta)("customer_phone"))}</span></div><div class="mb-1" data-v-61b273d7><span class="customer-email text-smaller" data-v-61b273d7>${ssrInterpolate(unref(meta)("customer_email"))}</span></div><div data-v-61b273d7><span class="customer-addr1" data-v-61b273d7>${ssrInterpolate(unref(meta)("customer_addr1"))}</span></div><div data-v-61b273d7><span class="customer-addr2" data-v-61b273d7>${ssrInterpolate(unref(meta)("customer_addr2"))}</span></div><div data-v-61b273d7><span class="customer-city" data-v-61b273d7>${ssrInterpolate(unref(meta)("customer_city"))}</span> <span class="customer-postal-code ml-3" data-v-61b273d7>${ssrInterpolate(unref(meta)("customer_postal_code"))}</span></div></div><ul class="order-items" style="${ssrRenderStyle(unref(order_item_styling))}" data-v-61b273d7><!--[-->`);
            ssrRenderList(unref(order_items), (o_item) => {
              _push(`<li class="items-start flex flex-col lg:flex-row py-6 border-b border-gray-200 gap-6 w-full" data-v-61b273d7><div class="product-image max-lg:w-full" data-v-61b273d7>`);
              if (o_item.image) {
                _push(`<img${ssrRenderAttr("src", o_item.image)} class="aspect-square w-full rounded-xl object-cover" data-v-61b273d7>`);
              } else {
                _push(`<!---->`);
              }
              _push(`</div><div class="flex flex-row items-center w-full" data-v-61b273d7><div class="grid grid-cols-1 lg:grid-cols-2 w-full" data-v-61b273d7><div class="flex items-center item-selections" data-v-61b273d7><div class="user-selection" data-v-61b273d7><h2 class="font-semibold text-larger leading-8 text-black mb-3" data-v-61b273d7>${ssrInterpolate(unref(product_title)(o_item))}</h2><p class="font-normal text-smaller leading-8 text-gray-500 mb-3" data-v-61b273d7> By: ${ssrInterpolate(unref(product_vendor)(o_item))}</p><div class="product-variant mb-2" data-v-61b273d7><span class="color-gray-500" data-v-61b273d7>${ssrInterpolate(unref(tf)(unref(product_variant)(o_item).name))}</span>: ${ssrInterpolate(unref(tf)(unref(product_variant)(o_item).value))}</div><!--[-->`);
              ssrRenderList(unref(product_choices)(o_item), (choice, c) => {
                _push(`<div class="mb-2" data-v-61b273d7><span class="mb-1 color-gray-600" data-v-61b273d7>${ssrInterpolate(unref(tf)(choice.name))}</span> : <span data-v-61b273d7>${ssrInterpolate(unref(tf)(choice.value))}</span></div>`);
              });
              _push(`<!--]--><div class="flex items-center quantity" data-v-61b273d7><span class="color-gray-600" data-v-61b273d7>Qty</span>: <span class="inline-block ml-2 text-gray-500" data-v-61b273d7>${ssrInterpolate(o_item.quantity)}</span></div>`);
              if (o_item.product_key) {
                _push(`<div class="product-license mt-5" data-v-61b273d7><div class="mb-1 color-gray-600" data-v-61b273d7>Product Key</div><div data-v-61b273d7><span class="inline-block cursor-default bg-primary-500 rounded bg-opacity-10 font-bold color-primary-500 px-2 py-1" data-v-61b273d7>${ssrInterpolate(o_item.product_key)}</span></div></div>`);
              } else {
                _push(`<!---->`);
              }
              _push(`</div></div><div class="grid grid-cols-5 item-overview" data-v-61b273d7><div class="col-span-5 lg:col-span-1 flex items-center max-lg:mt-3" data-v-61b273d7><div class="flex gap-3 lg:block" data-v-61b273d7><p class="font-bold leading-7 text-black" data-v-61b273d7>price</p><p class="lg:mt-4 color-primary-600" data-v-61b273d7>${ssrInterpolate(unref(prettify)(unref(product_price)(o_item)))}</p></div></div><div class="col-span-5 lg:col-span-2 flex items-center max-lg:mt-3" data-v-61b273d7><div class="flex gap-3 lg:block" data-v-61b273d7><p class="font-bold" data-v-61b273d7>status </p><p class="${ssrRenderClass([[unref(product_status)(o_item)], "whitespace-nowrap py-1 px-3 rounded-full lg:mt-3 bg-emerald-50 text-emerald-600 text-smaller"])}" data-v-61b273d7>${ssrInterpolate(unref(product_status)(o_item))}</p></div></div><div class="col-span-5 lg:col-span-2 flex items-center max-lg:mt-3" data-v-61b273d7><div class="flex gap-3 lg:block" data-v-61b273d7><p class="font-bold whitespace-nowrap" data-v-61b273d7> xDelivery</p><p class="whitespace-nowrap lg:mt-3 color-emerald-800" data-v-61b273d7>${ssrInterpolate(unref(product_delivery)(o_item))}</p></div></div></div></div></div></li>`);
            });
            _push(`<!--]--></ul><div class="w-full border-t border-gray-200 px-6 flex flex-col lg:flex-row items-center justify-between" data-v-61b273d7><div class="" data-v-61b273d7></div><div class="min-w-sm" data-v-61b273d7><div class="subtotal py-1 flex justify-between" data-v-61b273d7><span class="font-bold" data-v-61b273d7>Sub total</span> <span class="currency" data-v-61b273d7>${ssrInterpolate(unref(prettify)(unref(meta)("subtotal")))}</span></div><div class="subtotal py-1 flex justify-between" data-v-61b273d7><span class="font-bold" data-v-61b273d7>Shipping</span> <span class="currency" data-v-61b273d7>${ssrInterpolate(unref(prettify)(unref(meta)("shipping")))}</span></div><div class="total py-1 flex justify-between" data-v-61b273d7><span class="font-bold" data-v-61b273d7>Tax</span> <span class="currency" data-v-61b273d7>${ssrInterpolate(unref(prettify)(unref(meta)("tax")))}</span></div><div class="total py-1 flex justify-between" data-v-61b273d7><span class="font-bold" data-v-61b273d7>Total</span> <span class="currency" data-v-61b273d7>${ssrInterpolate(unref(prettify)(unref(meta)("total")))}</span></div></div></div></div>`);
          }
          _push(`<!--]-->`);
        }
        _push(`<!--]-->`);
      }
      _push(`</div>`);
    };
  }
};
const _sfc_setup = _sfc_main.setup;
_sfc_main.setup = (props, ctx) => {
  const ssrContext = useSSRContext();
  (ssrContext.modules || (ssrContext.modules = /* @__PURE__ */ new Set())).add("components/ROrderSummary.vue");
  return _sfc_setup ? _sfc_setup(props, ctx) : undefined;
};
const __nuxt_component_9 = /* @__PURE__ */ _export_sfc(_sfc_main, [["__scopeId", "data-v-61b273d7"]]);

export { __nuxt_component_9 as _ };
//# sourceMappingURL=ROrderSummary-B3BxuJJ5.mjs.map
