import { d as defineEventHandler, u as users, c as core, p as permissions, e as db } from '../../nitro/nitro.mjs';
import 'node:http';
import 'node:https';
import 'node:fs';
import 'node:path';
import 'jsonwebtoken';
import 'mysql2';
import 'child_process';
import 'crypto';
import 'stripe';
import 'node:fs/promises';
import 'fs';
import 'module';
import 'path';
import 'node-cron';
import 'node:url';

let report_published_posts = async () => {
  let N = db.name;
  let excluded_types = `"media","sniplet","layout"`;
  let t_posts = `${N}.posts`, t_act = `${N}.activities`, t_notes = `${N}.post_notes`;
  let views = `(SELECT Count(id) FROM ${t_act} WHERE post_id=T.id) as views`;
  let comments = `(SELECT Count(id) FROM ${t_notes} WHERE post_id=T.id) as comments`;
  let data = await db.query(`SELECT type, id,title,status, url,${views}, ${comments}  FROM ${t_posts} T  WHERE ${db.like("status", "published")} AND type not in (${excluded_types})  AND url is not null`);
  return {
    id: Date.now(),
    title: "Published Posts Views",
    type: "views",
    data,
    columns: [
      { name: "id", title: "ID" },
      { name: "type", title: "Type", width: "60px" },
      { name: "views", title: "Views", width: "85px" },
      { name: "comments", title: "Comments", width: "85px" },
      { name: "url", title: "URL" },
      { name: "title", title: "Title", width: "190px" },
      {
        name: "action",
        title: "Action",
        width: "220px",
        actions: [
          { name: "goto" }
        ]
      }
    ]
  };
};
let report_pending_comments = async () => {
  let N = db.name;
  let t_posts = `${N}.posts`, t_notes = `${N}.post_notes`, t_users = `${N}.users`;
  let url = `(SELECT url FROM ${t_posts} WHERE id=T.post_id) as url`;
  let username = `(SELECT name FROM ${t_users} WHERE id=T.created_by) as username`;
  let data = await db.query(`SELECT id, created_by, post_id ,status, value , created, ${url}, ${username} FROM ${t_notes} T WHERE ${db.like("status", ["pending"])}`);
  return {
    id: Date.now(),
    title: "New Comments",
    type: "new_comments",
    data,
    columns: [
      { name: "id", title: "ID" },
      { name: "username", title: "User", width: "95px" },
      { name: "value", title: "Comment" },
      { name: "created", title: "Date", width: "235px" },
      { name: "url", title: "URL" },
      {
        name: "action",
        title: "Action",
        width: "220px",
        actions: [
          { name: "goto" },
          { name: "delete_comment", title: "Trash" },
          { name: "approve_comment", title: "Approve" }
        ]
      }
    ]
  };
};
const analytics_post = defineEventHandler(async (event) => {
  if (!await users.is_logged_in({ event })) {
    return await core.res_denied(event, { msg: "You must be logged ", reason: "auth" });
  }
  let d = event.body;
  try {
    if (!await permissions.can_user({ user_id: event.user.id, action: "edit_options", evt: event }))
      return await core.res_denied(event, { msg: "Inadequate permission to view analytics", reason: "edit_options" });
    let promises = [];
    promises.push(report_published_posts());
    promises.push(report_pending_comments());
    d = await Promise.all(promises);
  } catch (e) {
    return await core.res_error(event, e);
  }
  return await core.res_success(event, { d, msg: "Site Analytics" });
});

export { analytics_post as default };
//# sourceMappingURL=analytics.post.mjs.map
