import { d as defineEventHandler, c as core, a as posts, b as plugin } from '../../nitro/nitro.mjs';
import 'node:http';
import 'node:https';
import 'node:fs';
import 'node:path';
import 'jsonwebtoken';
import 'mysql2';
import 'child_process';
import 'crypto';
import 'stripe';
import 'node:fs/promises';
import 'fs';
import 'module';
import 'path';
import 'node-cron';
import 'node:url';

let do_validation = (field_name, value, field_meta) => {
  console.log("<*>", field_name, value, field_meta);
  if (!field_meta) return { passed: true, errors: [] };
  let has_validation = () => {
    if (field_meta.required == true || field_meta.validation && field_meta.validation.length > 0) return true;
    return false;
  };
  if (!has_validation()) {
    return { passed: true, errors: [] };
  }
  let errors = [];
  let c_outcome = true, cond_met = null;
  if (field_meta.required) {
    let tmp_val = value;
    if (tmp_val != null && tmp_val.trim) {
      tmp_val = tmp_val.trim();
    }
    let has_value = tmp_val !== null && tmp_val !== "" && tmp_val !== " ";
    if (!has_value) errors.push("Field is required");
    c_outcome = c_outcome && has_value;
  }
  let validate = null;
  for (var i = 0; i < field_meta.validation.length; i++) {
    validate = field_meta.validation[i];
    if (validate.type == "number") {
      cond_met = core.is_num(value);
      if (cond_met && typeof value == "string") value = Number.parseFloat(value);
      if (!cond_met) errors.push("Field must be a number");
      c_outcome = c_outcome && cond_met;
    } else if (validate.type == "minmax") {
      var n = Number.parseFloat(value);
      cond_met = core.is_num(value) && n >= validate.min && n <= validate.max;
      if (!cond_met) errors.push(`Value must be between ${validate.min} and ${validate.max}`);
      c_outcome = c_outcome && cond_met;
    } else if (validate.type == "pattern") {
      var regex = new RegExp(validate.pattern);
      cond_met = regex.test(value);
      if (!cond_met) errors.push(`Value does not match expected pattern`);
      c_outcome = c_outcome && cond_met;
    } else if (["minlen", "maxlen"].includes(validate.type)) {
      if (validate.type == "minlen") {
        cond_met = value.length >= validate.min_len;
        if (!cond_met) errors.push(`Text length must be more than ${validate.min_len}`);
      } else {
        cond_met = value.length <= validate.max_len;
        if (!cond_met) errors.push(`Text length must be less than ${validate.max_len}`);
      }
      c_outcome = c_outcome && cond_met;
    } else if (validate.type == "phone") {
      var regex = new RegExp("^(1[ -]?)?\\d{3}[ -]?\\d{3}[ -]?\\d{4}$");
      cond_met = regex.test(value);
      if (!cond_met) errors.push(`Invalid phone number`);
      c_outcome = c_outcome && cond_met;
    } else if (validate.type == "email") {
      var regex = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
      cond_met = regex.test(value);
      if (!cond_met) errors.push(`Invalid email`);
      c_outcome = c_outcome && cond_met;
    } else if (validate.type == "date") {
      let is_date_valid = function(date_str) {
        return !isNaN(new Date(date_str));
      };
      cond_met = is_date_valid(value);
      if (!cond_met) errors.push(`Invalid date`);
      c_outcome = c_outcome && cond_met;
    }
  }
  return { passed: c_outcome, errors };
};
const forms_post = defineEventHandler(async (event) => {
  let d = [5, 66, "test", 33, 1];
  let body = event.body;
  if (!body) {
    return await core.res_denied(event, { d: null, msg: "Missing submission data.  Please try again", status: 400 });
  }
  if (!body._form_id) {
    return await core.res_denied(event, { d: null, msg: "Form ID is missing from submission", status: 400 });
  }
  let form_post = await posts.get_post({ id: body._form_id });
  if (!form_post) {
    return await core.res_denied(event, { d: null, status: 400, msg: `The form(${body._form_id}) either does not exist or is no longer active` });
  }
  let form_fields = await posts.get_form_fields(form_post);
  if (!form_fields) return core.res_denied(event, { d: null, msg: `Form definition does not have fields`, status: 400 });
  if (form_fields.__form.login_required && !event.user) {
    return await core.res_denied(event, { d: null, msg: `You must create an account or login in order to submit.`, status: 400 });
  }
  let validation_outcome;
  let validation_success = true;
  let clean_submission = {};
  let errors = [];
  for (var field_name in form_fields) {
    if (field_name == "__form") continue;
    validation_outcome = do_validation(field_name, body[field_name], form_fields[field_name]);
    validation_success = validation_success && validation_outcome.passed;
    if (!validation_outcome.passed) {
      errors.push(field_name + " : " + validation_outcome.errors.join(","));
    }
    clean_submission[field_name] = body[field_name];
  }
  if (errors.length > 0) {
    return await core.res_denied(event, { d: null, msg: `Form contains errors: ` + errors.join(";"), errors, status: 403 });
  }
  let new_post = {
    parent_id: body._form_id,
    type: "formdata",
    value: clean_submission,
    title: form_fields.__form.name + " Data",
    status: form_fields.__form.status || "pending",
    event
  };
  if (event.user) new_post.created_by = event.user.id;
  new_post = await posts.modify_post(new_post);
  plugin.do_action("new_submission", { value: new_post, form_id: body._form_id, form_name: body._form_name });
  return await core.res_success(event, { d, msg: "Form updated" });
});

export { forms_post as default };
//# sourceMappingURL=forms.post.mjs.map
